package Mail::TLSRPT;
# ABSTRACT: TLSRPT object
our $VERSION = '1.20200413.1'; # VERSION
use 5.20.0;
use Moo;
use Mail::TLSRPT::Pragmas;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Mail::TLSRPT - TLSRPT object

=head1 VERSION

version 1.20200413.1

=head1 DESCRIPTION

Classes to process tlsrpt reports

=head1 AUTHOR

Marc Bradshaw <marc@marcbradshaw.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by Marc Bradshaw.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
